@@ -47,6 +47,10 @@ class Windows(object): #pylint: disable-msg=R0902,R0904
         elif self._version_ex.major_version == 6:
             self._edition = self.get_windows6_edition()
             self.analyze_windows6_edition()
+            if self._version_ex.minor_version >= 2:
+                # http://msdn.microsoft.com/en-us/library/windows/desktop/ms724358(v=vs.85).aspx
+                # PRODUCT_*_SERVER_CORE values are not returned in Windows Server 2012
+                self.analyze_server_core_according_to_registry()
         else:
             self.edition = 'Unknown'
 
@@ -76,6 +80,29 @@ class Windows(object): #pylint: disable-msg=R0902,R0904
                             self._version_ex.service_pack_major,
                             self._version_ex.service_pack_minor)
 
+    def analyze_server_core_according_to_dism(self):
+        # http://stackoverflow.com/questions/13065479/how-to-detect-windows-2012-core-edition-c
+        from os import environ, path
+        from infi.execute import execute
+        SYSTEMROOT = environ.get("SystemRoot", path.join("C:", "Windows"))
+        dism = path.join(environ.get("SYSTEMROOT"), "System32", "dism.exe")
+        pid = execute([dism, "/online", "/get-features", "/format:table"])
+        self.server_core = any("ServerCore-FullServer" in line and "Disabled" in line for
+                               line in pid.get_stdout().splitlines())
+
+    def analyze_server_core_according_to_registry(self):
+        # http://msdn.microsoft.com/en-us/library/windows/desktop/hh846315%28v=vs.85%29.aspx
+        from infi.registry import LocalComputer
+        from infi.registry.errors import AccessDeniedException
+        KEY = r"SOFTWARE\Microsoft\Windows NT\CurrentVersion\Server\ServerLevels"
+        FEATURES = ("ServerCore", "Server-Gui-Mgmt", "Server-Gui-Shell")
+        try:
+            store = LocalComputer().local_machine[KEY].values_store
+        except AccessDeniedException:
+            self.analyze_server_core_according_to_dism()
+            return
+        self.server_core = all(item in store for item in FEATURES)
+
     def analyze_windows6_edition(self):
         from .constants import PRODUCT_SUITE_CLUSTER, PRODUCT_SUITE_DATACENTER
         from .constants import PRODUCT_SUITE_ENTERPRISE, PRODUCT_SUITE_STORAGE, PRODUCT_SUITE_STANDARD
@@ -175,4 +202,4 @@ class Windows(object): #pylint: disable-msg=R0902,R0904
         if os_name not in name_to_version:
             raise Exception("Could not find OS name {}".format(os_name))
         actual_version = (self._version_ex.major_version, self._version_ex.minor_version)
-        return actual_version > name_to_version[os_name]
\ No newline at end of file
+        return actual_version > name_to_version[os_name]
